<?php defined('_JEXEC') or die('Restricted access');

/**
 * @version 2.0 $Id: CommentHtmlUtils.php,v 1.9 2010-02-15 19:40:27 harry Exp $
 * @package Joomla
 * @subpackage H2N Link Directory 2
 * @copyright (C) 2008 - 2009 Harry Klein - www.joomla-hklein.de
 * @Copyright (C) 2006 Soner (pisdoktor) Ekici - www.sonerekici.com
 * @license GNU/GPL, see LICENSE.php
 * 
 * H2N Link Directory 2 is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.
 *
 * H2N Link Directory 2 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EventList; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

/**
 * Utils für das Kommentar-System.
 */
class CommentHtmlUtils {
		
	/**
	 * Liefert true, wenn das Kommentar-System 
	 * - eingeschaltet und 
	 * - auf internal gesetzt 
	 * ist, ansonsten false.
	 *
	 * @return true, wenn das Kommentar-System eingeschaltet und auf internal gesetzt ist, sonst false
	 */
	public function isInternActive(){
		require_once JPATH_COMPONENT_ADMINISTRATOR.DS.'LDConfig.php';
		$ld = new LDConfig();
		return $ld->commentlink && ($ld->commentSystem == 'intern');
	}
	
	/**
	 * Versucht, die Klassen von JComment zu laden. Bei Erfolg wird 
	 * true zurückgegeben, ansonten false.
	 * 
	 * @return true, wenn Laden der JComment-Klassen erfolgreich ist, ansonsten false
	 */
	public static function tryLoadJComment(){
		if (self::isJCommentInstalled()){
			$load = true;
			return self::isJCommentLinkdirecty2PluginInstalledAndTryLoad($load);
		}
		return false;
	}
	

	
	/** 
	 * Liefert true, wenn 
	 * 	1) JComment und 
	 *  2) JComment aktiviert (enabled) ist.
	 * 
	 * @return true, wenn JComment installiert und aktiviert ist, sonst false.
	 */
	public static function isJCommentInstalled(){
		jimport( 'joomla.application.component.helper' );
		$component = JComponentHelper::getComponent('com_jcomments',true);
		if ($component->enabled){
			return true;
		}
		return false;
	}
	
	/** 
	 * Liefert true, wenn 
	 * 	1) JComment und 
	 *  2) das entsprechende Linkdirectory-Plugin 
	 *  installiert sind und
	 *  3) JComment aktiviert (enabled) ist
	 * 
	 * 
	 * @return true, wenn JComment und das entsprechende Linkdirectory-Plugin installiert sind und JComment aktiviert ist, sonst false.
	 */
	public static function isJCommentUseable(){
		if (self::isJCommentInstalled()){
			$load = false;
			return self::isJCommentLinkdirecty2PluginInstalledAndTryLoad($load);
		}
		return false;
	}
	
	
	/**
	 * Liefert die Anzahl der Kommentare für den angegebenen Links. In Abhänigkeit 
	 * vom konfigurierten Kommentar-System wird das jeweilge System befragt. Kann 
	 * die Anzahl nicht ermittelt werden, wird -1 zurückgegeben. 
	 *
	 * @param int $id Id des Links
	 * @return Anzahl Kommentare eines Links
	 * @see CommentHtmlUtils::tryLoadJComment()
	 * @see JComments::getCommentsCount
	 * @see CommentHtmlUtils::getTotalInternComment($id)
	 */
	public static function getTotalComment(&$id) {
		require_once JPATH_COMPONENT_ADMINISTRATOR.DS.'LDConfig.php';
		$ld = new LDConfig();
		switch ($ld->commentSystem){
			case 'jcomment':
				if (CommentHtmlUtils::tryLoadJComment()){
					global $option;
					return JComments::getCommentsCount($id,$option);
		  		}
		  		break;
			case 'intern':
				return CommentHtmlUtils::getTotalInternComment($id);
				break;
		}	
		return -1;
	}

	/**
	 * Liefert einen HTML-Auswahlliste mit den verschiedenen Kategorienen für eine "Bad Link Report"
	 *
	 * @param int $active id des vorausgewälten Kategorie
	 * @return HTML der Auswahlliste mit den verschiedenen Kategorienen 
	 * 	für eine "Bad Link Report"
	 */
	public static function &getReportBadLinksOptionList($active=NULL){
		$options = array();
		$options[] = JHTML::_('select.option',1, JText::_('LD_R1'));
		$options[] = JHTML::_('select.option',2, JText::_('LD_R2'));
		$options[] = JHTML::_('select.option',3, JText::_('LD_R3'));
		$options[] = JHTML::_('select.option',4, JText::_('LD_R4'));
		$result = JHTML::_('select.genericlist',$options,'type',null,'value','text',$active);
		return $result;
	}
	
	private static function isJCommentLinkdirecty2PluginInstalledAndTryLoad ($load){
		global $option;				
		$comments = JPATH_SITE . DS.'components'.DS.'com_jcomments'.DS.'jcomments.php';
		$commentsClass = JPATH_SITE . DS.'components'.DS.'com_jcomments'.DS.'jcomments.class.php';
	 	if (file_exists($comments) && file_exists(JPATH_SITE .DS.'components'.DS.'com_jcomments'.DS.'plugins'.DS.$option.'.plugin.php')) {
			if ($load){
		    	require_once($comments);		    	
		    	require_once($commentsClass);
		  	}
		   	return true;
		 }
	  	return false;
	}
	
	/**
	 * Liefert Anzahl Kommentare des Links mit der Id $id.
	 *
	 * @param int $id
	 * @return Anzahl Kommentare eines Links
	 */
	private static function getTotalInternComment(&$id) {		
		$linkModel = JModel::getInstance('Link','LinkDirectory2Model');
		$linkModel->setId($id);
		return $linkModel->getTotalComments();

	}
}
?>